pkgs

package
v1.11.2-ext Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 20, 2026 License: Apache-2.0 Imports: 29 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ResolvingTestVariants

func ResolvingTestVariants() bool

ResolvingTestVariants reports whether the current process belongs to the nested test load used to construct synthetic dependency variants.

func Subscribe

func Subscribe(ctx context.Context, serverURL string, conn *nats.Conn, stats *common.CacheStats) (config.PackageLoader, error)

Types

type LoadRequest

type LoadRequest struct {
	Dir      string   `json:"dir"`      // The directory to resolve from (usually where `go.mod` is)
	Patterns []string `json:"patterns"` // Package pattern to resolve
}

LoadRequest is a request to load packages relative to a specific directory. It only loads the packages' names and (source) files, not their dependencies or export file. The result is cached for a given Dir+Pattern pair. Each pattern is loaded individually (so that they can be cached independently).

func (LoadRequest) ForeachSpanTag

func (r LoadRequest) ForeachSpanTag(set func(key string, value any))

func (LoadRequest) ResponseIs

func (LoadRequest) ResponseIs(LoadResponse)

func (LoadRequest) Subject

func (LoadRequest) Subject() string

type LoadResponse

type LoadResponse []*packages.Package

LoadResponse is the response to a LoadRequest. It contains the packages that were loaded.

type ResolveRequest

type ResolveRequest struct {
	Dir            string   `json:"dir"`                      // The directory to resolve from (usually where `go.mod` is)
	Env            []string `json:"env"`                      // Environment variables to use during resolution
	Pattern        string   `json:"pattern"`                  // Package pattern to resolve
	TempDir        string   `json:"tmpdir,omitempty"`         // A temporary directory to use for Go build artifacts
	TestVariantFor string   `json:"testVariantFor,omitempty"` // Resolve the literal Pattern as built for this package's tests
	// contains filtered or unexported fields
}

func NewResolveRequest

func NewResolveRequest(dir string, pattern string) ResolveRequest

func (ResolveRequest) ForeachSpanTag

func (r ResolveRequest) ForeachSpanTag(set func(key string, value any))

func (ResolveRequest) ResponseIs

func (ResolveRequest) ResponseIs(ResolveResponse)

func (ResolveRequest) Subject

func (ResolveRequest) Subject() string

type ResolveResponse

type ResolveResponse map[string]ResolvedArchive

ResolveResponse maps package import paths to their resolved export archives.

type ResolvedArchive

type ResolvedArchive struct {
	ExportFile string `json:"exportFile"`
	ForTest    string `json:"forTest,omitempty"`
}

ResolvedArchive identifies an export archive and, when non-empty, the test target for which Go rebuilt it.

Jump to